pysmime.util.BadKeyringSource

Package pysmime :: Module util :: Class BadKeyringSource |
[hide private]
[frames] | no frames]

# Class BadKeyringSource

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
                              BadKeyringSource

Exception raised if selected Keyring source is not valid. Ammitted values are file, memory and pkcs11.

Instance Methods | [hide private]
Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__init__`, `__new__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`